@@ -26,9 +26,8 @@
 # include "config.h"
 #endif
 
-#include "geanyplugin.h"
-
-#include "scintilla/SciLexer.h"
+#include <geanyplugin.h>
+#include <scintilla/SciLexer.h>
 
 #include <string.h>
 #include <ctype.h>
@@ -54,7 +53,7 @@ static void dict_describe(const gchar* const lang, const gchar* const name,
 
 static gboolean is_word_sep(gunichar c)
 {
-	return (g_unichar_isspace(c) || g_unichar_ispunct(c)) && c != (gunichar)'\'';
+	return g_unichar_isspace(c) || g_unichar_ispunct(c);
 }
 
 
@@ -95,7 +94,7 @@ static gchar *strip_word(const gchar *word_to_check, gint *result_offset)
 	g_memmove(word_start, word, new_word_len);
 	word = word_start;
 	word[new_word_len] = '\0';
-	if (! NZV(word))
+	if (EMPTY(word))
 	{
 		g_free(word);
 		return NULL;
@@ -146,7 +145,7 @@ static gint sc_speller_check_word(GeanyDocument *doc, gint line_number, const gc
 
 	/* strip punctuation and white space */
 	word_to_check = strip_word(word, &offset);
-	if (! NZV(word_to_check))
+	if (EMPTY(word_to_check))
 	{
 		g_free(word_to_check);
 		return 0;
@@ -199,48 +198,61 @@ static gint sc_speller_check_word(GeanyDocument *doc, gint line_number, const gc
 }
 
 
-gint sc_speller_process_line(GeanyDocument *doc, gint line_number, const gchar *line)
+gint sc_speller_process_line(GeanyDocument *doc, gint line_number)
 {
 	gint pos_start, pos_end;
 	gint wstart, wend;
-	GString *str;
 	gint suggestions_found = 0;
+	gint wordchars_len;
+	gchar *wordchars;
 
 	g_return_val_if_fail(sc_speller_dict != NULL, 0);
 	g_return_val_if_fail(doc != NULL, 0);
-	g_return_val_if_fail(line != NULL, 0);
 
-	str = g_string_sized_new(256);
+	/* add ' (single quote) temporarily to wordchars
+	 * to be able to check for "doesn't", "isn't" and similar */
+	wordchars_len = scintilla_send_message(doc->editor->sci, SCI_GETWORDCHARS, 0, 0);
+	wordchars = g_malloc0(wordchars_len + 2); /* 2 = temporarily added "'" and "\0" */
+	scintilla_send_message(doc->editor->sci, SCI_GETWORDCHARS, 0, (sptr_t)wordchars);
+	if (! strchr(wordchars, '\''))
+	{
+		/* temporarily add "'" to the wordchars */
+		wordchars[wordchars_len] = '\'';
+		scintilla_send_message(doc->editor->sci, SCI_SETWORDCHARS, 0, (sptr_t)wordchars);
+	}
 
 	pos_start = sci_get_position_from_line(doc->editor->sci, line_number);
 	pos_end = sci_get_position_from_line(doc->editor->sci, line_number + 1);
 
 	while (pos_start < pos_end)
 	{
+		gchar *word;
+
 		wstart = scintilla_send_message(doc->editor->sci, SCI_WORDSTARTPOSITION, pos_start, TRUE);
 		wend = scintilla_send_message(doc->editor->sci, SCI_WORDENDPOSITION, wstart, FALSE);
 		if (wstart == wend)
 			break;
 
-		/* ensure the string has enough allocated memory */
-		if (str->len < (guint)(wend - wstart))
-			g_string_set_size(str, wend - wstart);
+		word = sci_get_contents_range(doc->editor->sci, wstart, wend);
 
-		sci_get_text_range(doc->editor->sci, wstart, wend, str->str);
-
-		suggestions_found += sc_speller_check_word(doc, line_number, str->str, wstart, wend);
+		suggestions_found += sc_speller_check_word(doc, line_number, word, wstart, wend);
 
 		pos_start = wend + 1;
+
+		g_free(word);
 	}
 
-	g_string_free(str, TRUE);
+	/* reset wordchars for the current document */
+	wordchars[wordchars_len] = '\0';
+	scintilla_send_message(doc->editor->sci, SCI_SETWORDCHARS, 0, (sptr_t)wordchars);
+
+	g_free(wordchars);
 	return suggestions_found;
 }
 
 
 void sc_speller_check_document(GeanyDocument *doc)
 {
-	gchar *line;
 	gint i;
 	gint first_line, last_line;
 	gchar *dict_string = NULL;
@@ -280,22 +292,16 @@ void sc_speller_check_document(GeanyDocument *doc)
 
 	if (first_line == last_line)
 	{
-		line = sci_get_selection_contents(doc->editor->sci);
-		suggestions_found += sc_speller_process_line(doc, first_line, line);
-		g_free(line);
+		suggestions_found += sc_speller_process_line(doc, first_line);
 	}
 	else
 	{
 		for (i = first_line; i < last_line; i++)
 		{
-			line = sci_get_line(doc->editor->sci, i);
-
-			suggestions_found += sc_speller_process_line(doc, i, line);
+			suggestions_found += sc_speller_process_line(doc, i);
 
 			/* process other GTK events to keep the GUI being responsive */
 			while (g_main_context_iteration(NULL, FALSE));
-
-			g_free(line);
 		}
 	}
 	if (suggestions_found == 0 && sc_info->use_msgwin)
@@ -308,9 +314,16 @@ void sc_speller_check_document(GeanyDocument *doc)
 static void broker_init_failed(void)
 {
 	const gchar *err = enchant_broker_get_error(sc_speller_broker);
-	dialogs_show_msgbox(GTK_MESSAGE_ERROR,
+	gchar *msg = g_strdup_printf(
 		_("The Enchant library couldn't be initialized (%s)."),
 		(err != NULL) ? err : _("unknown error (maybe the chosen language is not available)"));
+
+	msgwin_status_add("%s", msg);
+	if (main_is_realized())
+		/* show dialog only after Geany has been loaded already, i.e. not while starting up */
+		dialogs_show_msgbox(GTK_MESSAGE_ERROR, "%s", msg);
+
+	g_free(msg);
 }
 
 
@@ -375,7 +388,10 @@ static void add_dict_array(const gchar* const lang_tag, const gchar* const provi
 	for (i = 0; i < sc_info->dicts->len; i++)
 	{
 		if (utils_str_equal(g_ptr_array_index(sc_info->dicts, i), result))
+		{
+			g_free(result);
 			return;
+		}
 	}
 
 	g_ptr_array_add(sc_info->dicts, result);
@@ -701,6 +717,24 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 			}
 			break;
 		}
+		case SCLEX_COFFEESCRIPT:
+		{
+			switch (style)
+			{
+				case SCE_COFFEESCRIPT_CHARACTER:
+				case SCE_COFFEESCRIPT_COMMENTBLOCK:
+				case SCE_COFFEESCRIPT_COMMENTDOCKEYWORD:
+				case SCE_COFFEESCRIPT_COMMENTDOCKEYWORDERROR:
+				case SCE_COFFEESCRIPT_COMMENTLINEDOC:
+				case SCE_COFFEESCRIPT_STRING:
+				case SCE_COFFEESCRIPT_STRINGEOL:
+				case SCE_COFFEESCRIPT_STRINGRAW:
+					return TRUE;
+				default:
+					return FALSE;
+			}
+			break;
+		}
 		case SCLEX_CSS:
 		{
 			switch (style)
@@ -845,41 +879,34 @@ gboolean sc_speller_is_text(GeanyDocument *doc, gint pos)
 				case SCE_H_SGML_DOUBLESTRING:
 				case SCE_H_SGML_SIMPLESTRING:
 				case SCE_H_SGML_1ST_PARAM_COMMENT:
-				case SCE_HJ_DEFAULT:
 				case SCE_HJ_COMMENT:
 				case SCE_HJ_COMMENTLINE:
 				case SCE_HJ_COMMENTDOC:
 				case SCE_HJ_DOUBLESTRING:
 				case SCE_HJ_SINGLESTRING:
 				case SCE_HJ_STRINGEOL:
-				case SCE_HB_DEFAULT:
 				case SCE_HB_COMMENTLINE:
 				case SCE_HB_STRING:
 				case SCE_HB_STRINGEOL:
-				case SCE_HBA_DEFAULT:
 				case SCE_HBA_COMMENTLINE:
 				case SCE_HBA_STRING:
 				case SCE_HBA_STRINGEOL:
-				case SCE_HJA_DEFAULT:
 				case SCE_HJA_COMMENT:
 				case SCE_HJA_COMMENTLINE:
 				case SCE_HJA_COMMENTDOC:
 				case SCE_HJA_DOUBLESTRING:
 				case SCE_HJA_SINGLESTRING:
 				case SCE_HJA_STRINGEOL:
-				case SCE_HP_DEFAULT:
 				case SCE_HP_COMMENTLINE:
 				case SCE_HP_STRING:
 				case SCE_HP_CHARACTER:
 				case SCE_HP_TRIPLE:
 				case SCE_HP_TRIPLEDOUBLE:
-				case SCE_HPA_DEFAULT:
 				case SCE_HPA_COMMENTLINE:
 				case SCE_HPA_STRING:
 				case SCE_HPA_CHARACTER:
 				case SCE_HPA_TRIPLE:
 				case SCE_HPA_TRIPLEDOUBLE:
-				case SCE_HPHP_DEFAULT:
 				case SCE_HPHP_SIMPLESTRING:
 				case SCE_HPHP_HSTRING:
 				case SCE_HPHP_COMMENT:
